from unittest import TestCase

from lazy_ouch.core import CustomError


class CustomErrorTests(TestCase):

    def test_custom_error_message(self):
        ce = CustomError()
        self.assertEqual("CustomError - Custom Exception(Base)", ce.prepare_err_message())
        self.assertEqual("CustomError - Custom Exception(Base)", ce.prepare_description())
        self.assertEqual("", ce.prepare_args())
        self.assertEqual("", ce.prepare_kwargs())



__all__ = [
    "CustomError"
]


class CustomError(BaseException):
    """Custom Exception(Base)"""
    include_err_name = True

    def prepare_description(self):
        desc = self.__doc__
        if self.include_err_name:
            desc = "{} - {}".format(type(self).__name__, desc)
        return desc

    @staticmethod
    def prepare_args(*args) -> str:
        return ", ".join(
            [
                str(arg)
                for arg in args
            ])

    @staticmethod
    def prepare_kwargs(**kwargs) -> str:
        return ", ".join([
            "{}={}".format(k, v)
            for k, v in kwargs.items()
        ])

    def prepare_err_message(self, *args, **kwargs):
        return "{}{}{}".format(self.prepare_description(),
                               self.prepare_args(*args),
                               self.prepare_kwargs(**kwargs))

    def __init__(self, *args, **kwargs):
        super().__init__(self.prepare_err_message(*args, **kwargs))



from setuptools import find_packages, setup
import os

readme_file = os.path.join(os.path.dirname(__file__), "README.md")

with open(readme_file) as readme:
    README = "{}".format(readme.read())
README = README.replace(README.split("# Install")[0], "")

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))


setup(
    name="lazy_ouch",
    version="0.0.2",
    packages=find_packages(),
    include_package_data=True,
    license="BSD License",
    description="Lazy way to use custom exceptions",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/TokkoLabs/services-tokkobroker/libraries/",
    author="Jose Salgado",
    author_email="jsalgado@navent.com",
    install_requires=[

    ],
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
    ],
)
